aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/install/database_update.php
diff options
context:
space:
mode:
authorAndreas Fischer <bantu@phpbb.com>2011-07-07 20:19:11 +0200
committerAndreas Fischer <bantu@phpbb.com>2011-07-07 20:19:11 +0200
commit787245a113bc8a4d99050414fd06662c60cc2e57 (patch)
treed71e97a2e70d0204cf65fd550c02e10163941d59 /phpBB/install/database_update.php
parent5fefdecc50b421afc081493541b0679e83b8f323 (diff)
downloadforums-787245a113bc8a4d99050414fd06662c60cc2e57.tar
forums-787245a113bc8a4d99050414fd06662c60cc2e57.tar.gz
forums-787245a113bc8a4d99050414fd06662c60cc2e57.tar.bz2
forums-787245a113bc8a4d99050414fd06662c60cc2e57.tar.xz
forums-787245a113bc8a4d99050414fd06662c60cc2e57.zip
[prep-release-3.0.9] Decreasing version for an RC4 release.
Diffstat (limited to 'phpBB/install/database_update.php')
-rw-r--r--phpBB/install/database_update.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/install/database_update.php b/phpBB/install/database_update.php
index ac08466a01..097f6302dc 100644
--- a/phpBB/install/database_update.php
+++ b/phpBB/install/database_update.php
@@ -8,7 +8,7 @@
*
*/
-define('UPDATES_TO_VERSION', '3.0.9');
+define('UPDATES_TO_VERSION', '3.0.9-RC4');
// Enter any version to update from to test updates. The version within the db will not be updated.
define('DEBUG_FROM_VERSION', false);
@@ -979,7 +979,7 @@ function database_update_info()
'3.0.9-RC1' => array(),
// No changes from 3.0.9-RC2 to 3.0.9-RC3
'3.0.9-RC2' => array(),
// No changes from 3.0.9-RC3 to 3.0.9
'3.0.9-RC3' => array(),
/** @todo DROP LOGIN_ATTEMPT_TABLE.attempt_id in 3.0.10-RC1 */
@@ -1983,7 +1983,7 @@ function change_database_data(&$no_updates, $version)
case '3.0.9-RC2':
break;
// No changes from 3.0.9-RC3 to 3.0.9
case '3.0.9-RC3':
break;
}
@@ -979,7 +979,7 @@ function database_update_info()
// No changes from 3.0.9-RC2 to 3.0.9-RC3
'3.0.9-RC2' => array(),
- // No changes from 3.0.9-RC3 to 3.0.9
+ // No changes from 3.0.9-RC3 to 3.0.9-RC4
'3.0.9-RC3' => array(),
/** @todo DROP LOGIN_ATTEMPT_TABLE.attempt_id in 3.0.10-RC1 */
@@ -1983,7 +1983,7 @@ function change_database_data(&$no_updates, $version)
case '3.0.9-RC2':
break;
- // No changes from 3.0.9-RC3 to 3.0.9
+ // No changes from 3.0.9-RC3 to 3.0.9-RC4
case '3.0.9-RC3':
break;